<header>
<p align="center">
    <img src=".github/images/geoid-logo_light.png" width="20%" height="20%" alt="Geoid Logo">
</p>
<p align='center' style='border-bottom: none;'><b>Geoid</b></p>
<h1 align='center' style='border-bottom: none;'>Dymaxion</h1>
<h3 align='center'>Unit Geometry Library</h3>
</header>


<br/>
<details open="open">
<summary>Table of Contents</summary>

- [About](#about)
- [Quick Start](#quick-start)
- [Usage](#usage)
- [Authors](#authors)
- [Roadmap](#roadmap)
- [Contributing](#contributing)
- [License](#license)
- [Disclaimer](#disclaimer)
- [Links](#links)


</details>



## About



## Quick Start

...


## Usage

...




## Authors

**Dymaxion** is an open-source project by **[Geoid](https://www.geoid.org "Geoid website")**.

**Geoid is a spatial operating system that covers our entire planet with an extended intelligent dimension.**
This self-organizing network bridges our virtual and physical environments and is formed by all the people of our planet and the information and communication technologies that connect them. Geoid functions as a nervous system that mediates the data we produce and use in our daily lives, adds value to interconnectivity and cherishes spontaneous connections between people and the places and things they love.

website: [www.geoid.org](https://www.geoid.org "Geoid website")


## Roadmap

...


## Contributing

We'd love for you to contribute and to make **Dymaxion** even better than it is today!
Please refer to the [contribution guidelines](.github/CONTRIBUTING.md) for information.


## License


Except where otherwise noted, **Dymaxion** by Geoid is licensed under the terms of the [Creative Commons Attribution-ShareAlike 4.0 International License](https://creativecommons.org/licenses/by-sa/4.0/ "Creative Commons Attribution-ShareAlike 4.0 International License"). To view a copy of this license, visit [https://creativecommons.org/licenses/by-sa/4.0/](https://creativecommons.org/licenses/by-sa/4.0/ "Creative Commons Attribution-ShareAlike 4.0 International License") or write to Creative Commons, 171 Second Street, Suite 300, San Francisco, CA 94105, USA.



## Disclaimer

**THIS SOFTWARE IS PROVIDED AS IS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING ANY IMPLIED WARRANTIES OF FITNESS FOR A PARTICULAR PURPOSE, MERCHANTABILITY, OR NON-INFRINGEMENT.**

